@@ -16,9 +16,9 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 require 'gem2deb'
+require 'gem2deb/yaml'
 require 'gem2deb/metadata'
 require 'rubygems'
-require 'yaml'
 require 'fileutils'
 require 'erb'
 require 'date'
